@@ -9,29 +9,39 @@
         <translation>ضبط لكسكيوت لسمة الفأرة</translation>
     </message>
     <message>
-        <location filename="../selectwnd.ui" line="20"/>
+        <location filename="../selectwnd.ui" line="46"/>
         <source>Select the cursor theme you want to use (hover preview to test cursor). &lt;b&gt;LXQt session needs restart after this change&lt;/b&gt;:</source>
-        <translation>اختر سمة المؤشّر لاستخدامها (ضع المؤشّر على المعاينة لاختباره). &lt;b&gt;يجب إعادة تشغيل جلسة لكسكيوت بعد تغيير هذا&lt;/b&gt;:</translation>
+        <translation>اختر سمة المؤشّر التي تريد استعمالها (ضع مؤشّر الفأرة على المعاينة لاختبار السمة). &lt;b&gt;عليك إعادة تشغيل جلسة «لكسكيوت» بعد تغيير هذا&lt;/b&gt;:</translation>
     </message>
     <message>
-        <location filename="../selectwnd.ui" line="81"/>
+        <location filename="../selectwnd.ui" line="23"/>
         <source>&amp;Install New Theme...</source>
         <translation>&amp;ثبّت سمة جديدة...</translation>
     </message>
     <message>
-        <location filename="../selectwnd.ui" line="88"/>
+        <location filename="../selectwnd.ui" line="72"/>
+        <source>LXQt session needs restart to view this change.</source>
+        <translation>عليك إعادة تشغيل جلسة «لكسكيوت» لعرض هذا التعديل.</translation>
+    </message>
+    <message>
+        <location filename="../selectwnd.ui" line="91"/>
         <source>&amp;Remove Theme</source>
         <translation>أ&amp;زِل السمة</translation>
     </message>
     <message>
-        <location filename="../selectwnd.cpp" line="212"/>
+        <location filename="../selectwnd.ui" line="111"/>
+        <source>Size</source>
+        <translation>المقاس</translation>
+    </message>
+    <message>
+        <location filename="../selectwnd.cpp" line="233"/>
         <source>XCurTheme error</source>
         <translation>خطأ XCurTheme</translation>
     </message>
     <message>
-        <location filename="../selectwnd.cpp" line="213"/>
+        <location filename="../selectwnd.cpp" line="234"/>
         <source>You can&apos;t remove active theme!</source>
-        <translation>لا يمكنك إزالة سمة نشطة!</translation>
+        <translation>لا يمكنك إزالة السمة النشطة!</translation>
     </message>
 </context>
 <context>
@@ -44,7 +54,7 @@
     <message>
         <location filename="../warninglabel.ui" line="44"/>
         <source>LXQt could not find any cursor theme. The default X11 cursor theme will be used instead. LXQt looked in the following directories:</source>
-        <translation>تعذر على لكسكيوت العثور على أية سمة أيقونات. ستُستخدم سمة مؤشّرات X11 المبدئية. بحثت لكسكيوت في الأدلة الآتية:</translation>
+        <translation>تعذّر على «لكسكيوت» العثور على أية سمة أيقونات. ستُستعمل سمة مؤشّرات X11 المبدئية. بحثت «لكسكيوت» في الأدلة الآتية:</translation>
     </message>
     <message>
         <location filename="../warninglabel.ui" line="54"/>
