@@ -9,27 +9,37 @@
         <translation>LXQt configuration du thème de la souris</translation>
     </message>
     <message>
-        <location filename="../selectwnd.ui" line="20"/>
+        <location filename="../selectwnd.ui" line="46"/>
         <source>Select the cursor theme you want to use (hover preview to test cursor). &lt;b&gt;LXQt session needs restart after this change&lt;/b&gt;:</source>
-        <translation>Sélectionnez le thème de curseur que vous souhaitez utiliser (aperçu au survol pour tester le curseur). &lt;b&gt;La session LXQt doit être redémarrée après cette modification&lt;/b&gt; :</translation>
+        <translation>Sélectionner le thème de curseur que vous souhaitez utiliser (aperçu au survol pour tester le curseur). &lt;b&gt;La session LXQt doit être redémarrée après cette modification&lt;/b&gt; :</translation>
     </message>
     <message>
-        <location filename="../selectwnd.ui" line="81"/>
+        <location filename="../selectwnd.ui" line="23"/>
         <source>&amp;Install New Theme...</source>
         <translation>&amp;Installer le nouveau thème...</translation>
     </message>
     <message>
-        <location filename="../selectwnd.ui" line="88"/>
+        <location filename="../selectwnd.ui" line="72"/>
+        <source>LXQt session needs restart to view this change.</source>
+        <translation>Pour observer les changements, la session LXQt doit être redémarrée.</translation>
+    </message>
+    <message>
+        <location filename="../selectwnd.ui" line="91"/>
         <source>&amp;Remove Theme</source>
         <translation>&amp;Supprimer le thème</translation>
     </message>
     <message>
-        <location filename="../selectwnd.cpp" line="212"/>
+        <location filename="../selectwnd.ui" line="111"/>
+        <source>Size</source>
+        <translation>Taille</translation>
+    </message>
+    <message>
+        <location filename="../selectwnd.cpp" line="233"/>
         <source>XCurTheme error</source>
         <translation>Erreur XCurTheme</translation>
     </message>
     <message>
-        <location filename="../selectwnd.cpp" line="213"/>
+        <location filename="../selectwnd.cpp" line="234"/>
         <source>You can&apos;t remove active theme!</source>
         <translation>Vous ne pouvez pas supprimer le thème actuel !</translation>
     </message>
