@@ -6,32 +6,42 @@
     <message>
         <location filename="../selectwnd.ui" line="14"/>
         <source>LXQt Mouse Theme Configuration</source>
-        <translation>LXQtマウステーマの設定</translation>
+        <translation>LXQt マウステーマの設定</translation>
     </message>
     <message>
-        <location filename="../selectwnd.ui" line="20"/>
+        <location filename="../selectwnd.ui" line="46"/>
         <source>Select the cursor theme you want to use (hover preview to test cursor). &lt;b&gt;LXQt session needs restart after this change&lt;/b&gt;:</source>
-        <translation>使いたいカーソルテーマを選択 (プレビューをテストカーソルに合わせます). &lt;b&gt;LXQtセッションはこの変更後に再起動が必要です&lt;/b&gt;:</translation>
+        <translation>使いたいカーソルテーマを選択して下さい (カーソルをテストするにはマウスをプレビューの上に合わせます)。&lt;b&gt;この変更後に LXQt セッションの再起動が必要です&lt;/b&gt;:</translation>
     </message>
     <message>
-        <location filename="../selectwnd.ui" line="81"/>
+        <location filename="../selectwnd.ui" line="23"/>
         <source>&amp;Install New Theme...</source>
         <translation>新しいテーマのインストール(&amp;I)...</translation>
     </message>
     <message>
-        <location filename="../selectwnd.ui" line="88"/>
+        <location filename="../selectwnd.ui" line="72"/>
+        <source>LXQt session needs restart to view this change.</source>
+        <translation>この変更を表示するには LXQt セッションを再起動して下さい。</translation>
+    </message>
+    <message>
+        <location filename="../selectwnd.ui" line="91"/>
         <source>&amp;Remove Theme</source>
         <translation>テーマの削除(&amp;R)</translation>
     </message>
     <message>
-        <location filename="../selectwnd.cpp" line="212"/>
+        <location filename="../selectwnd.ui" line="111"/>
+        <source>Size</source>
+        <translation>サイズ</translation>
+    </message>
+    <message>
+        <location filename="../selectwnd.cpp" line="233"/>
         <source>XCurTheme error</source>
         <translation>XCurTheme エラー</translation>
     </message>
     <message>
-        <location filename="../selectwnd.cpp" line="213"/>
+        <location filename="../selectwnd.cpp" line="234"/>
         <source>You can&apos;t remove active theme!</source>
-        <translation>アクティブなテーマは削除できません!</translation>
+        <translation>アクティブなテーマは削除できません！</translation>
     </message>
 </context>
 <context>
@@ -44,7 +54,7 @@
     <message>
         <location filename="../warninglabel.ui" line="44"/>
         <source>LXQt could not find any cursor theme. The default X11 cursor theme will be used instead. LXQt looked in the following directories:</source>
-        <translation>カーソルテーマを見つけられませんでした。代わりに、デフォルトのX11カーソルテーマが使われます。LXQtは以下のディレクトリーを検索しました:</translation>
+        <translation>カーソルテーマを見つけられませんでした。代わりに、デフォルトの X11 カーソルテーマが使われます。次のディレクトリを探しました:</translation>
     </message>
     <message>
         <location filename="../warninglabel.ui" line="54"/>
