@@ -41,7 +41,7 @@ static const char *curShapeName[] = {
   "SizeAll",
   "Wait",
   "NO",
-  0
+  nullptr
 };
 
 
@@ -53,7 +53,7 @@ static const char *findCurShapeName (const QString &s) {
     if (!strcasecmp(name, *nlst)) return *nlst;
     nlst++;
   }
-  return 0;
+  return nullptr;
 }
 
 
@@ -324,7 +324,7 @@ bool XCursorThemeXP::parseCursorXPTheme (const QDir &thDir) {
             // copy frame
             QImage frame(img.copy(fNo*frameWdt, 0, frameWdt, img.height()));
             //frame.save(QString("_png/%1_%2.png").arg(cim->name()).arg(QString::number(f)));
-            XCursorImage *i = new XCursorImage(QStringLiteral("%1%2").arg(cim->name()).arg(QString::number(fCnt)),
+            XCursorImage *i = new XCursorImage(QStringLiteral("%1%2").arg(cim->name(), QString::number(fCnt)),
               frame, info.xhot, info.yhot, a.delay, 1
             );
             cim->append(i);
