@@ -1,15 +1,28 @@
 <?xml version="1.0" encoding="utf-8"?>
 <!DOCTYPE TS>
 <TS version="2.1" language="el">
+<context>
+    <name>ColorLabel</name>
+    <message>
+        <location filename="../colorLabel.cpp" line="37"/>
+        <source>Click to change color.</source>
+        <translation>Κλικ για να αλλάξετε χρώμα.</translation>
+    </message>
+    <message>
+        <location filename="../colorLabel.cpp" line="61"/>
+        <source>Select Color</source>
+        <translation>Επιλογή χρώματος</translation>
+    </message>
+</context>
 <context>
     <name>ConfigOtherToolKits</name>
     <message>
-        <location filename="../configothertoolkits.cpp" line="147"/>
+        <location filename="../configothertoolkits.cpp" line="148"/>
         <source>GTK themes</source>
         <translation>Θέματα GTK</translation>
     </message>
     <message>
-        <location filename="../configothertoolkits.cpp" line="148"/>
+        <location filename="../configothertoolkits.cpp" line="149"/>
         <source>&lt;p&gt;&apos;%1&apos; has been overwritten.&lt;/p&gt;&lt;p&gt;You can find a copy of your old settings in &apos;%2&apos;&lt;/p&gt;</source>
         <translation>&lt;p&gt;Το %1 αντικαταστάθηκε.&lt;/p&gt;&lt;p&gt;Μπορείτε να βρείτε ένα αντίγραφο της παλιάς διαμόρφωσης στο &apos;%2&apos;&lt;/p&gt;</translation>
     </message>
@@ -34,7 +47,7 @@
     <message>
         <location filename="../fontsconfig.ui" line="46"/>
         <source>Style:</source>
-        <translation>Ύφος:</translation>
+        <translation>Τεχνοτροπία:</translation>
     </message>
     <message>
         <location filename="../fontsconfig.ui" line="53"/>
@@ -74,7 +87,7 @@
     <message>
         <location filename="../fontsconfig.ui" line="107"/>
         <source>Font hinting style:</source>
-        <translation>Ύφος υπόδειξης των γραμματοσειρών:</translation>
+        <translation>Τεχνοτροπία υπόδειξης των γραμματοσειρών:</translation>
     </message>
     <message>
         <location filename="../fontsconfig.ui" line="118"/>
@@ -210,73 +223,128 @@
 <context>
     <name>StyleConfig</name>
     <message>
-        <location filename="../styleconfig.ui" line="23"/>
+        <location filename="../styleconfig.ui" line="33"/>
         <source>Widget Style</source>
         <translation>Τεχνοτροπία συστατικού</translation>
     </message>
     <message>
-        <location filename="../styleconfig.ui" line="42"/>
+        <location filename="../styleconfig.ui" line="63"/>
+        <source>Qt Palette</source>
+        <translation>Χρωματοπυξίδα Qt</translation>
+    </message>
+    <message>
+        <location filename="../styleconfig.ui" line="77"/>
+        <source>Some Qt styles may ignore these colors.</source>
+        <translation>Μερικές τεχνοτροπίες Qt μπορεί να αγνοούν αυτά τα χρώματα.</translation>
+    </message>
+    <message>
+        <location filename="../styleconfig.ui" line="102"/>
+        <source>Window:</source>
+        <translation>Παράθυρο:</translation>
+    </message>
+    <message>
+        <location filename="../styleconfig.ui" line="112"/>
+        <source>View:</source>
+        <translation>Προβολή:</translation>
+    </message>
+    <message>
+        <location filename="../styleconfig.ui" line="122"/>
+        <source>Selection:</source>
+        <translation>Επιλογή:</translation>
+    </message>
+    <message>
+        <location filename="../styleconfig.ui" line="132"/>
+        <source>Link:</source>
+        <translation>Σύνδεσμος:</translation>
+    </message>
+    <message>
+        <location filename="../styleconfig.ui" line="152"/>
+        <source>Window Text:</source>
+        <translation>Κείμενο παραθύρου:</translation>
+    </message>
+    <message>
+        <location filename="../styleconfig.ui" line="162"/>
+        <source>View Text:</source>
+        <translation>Προβολή κειμένου:</translation>
+    </message>
+    <message>
+        <location filename="../styleconfig.ui" line="172"/>
+        <source>Selected Text:</source>
+        <translation>Επιλεγμένο κείμενο:</translation>
+    </message>
+    <message>
+        <location filename="../styleconfig.ui" line="182"/>
+        <source>Visited Link:</source>
+        <translation>Επισκεφθέν δεσμός:</translation>
+    </message>
+    <message>
+        <location filename="../styleconfig.ui" line="227"/>
+        <source>&amp;Default Palette</source>
+        <translation>&amp;Προκαθορισμένη χρωματοπυξίδα</translation>
+    </message>
+    <message>
+        <location filename="../styleconfig.ui" line="254"/>
         <source>Set GTK themes (GTK configuration files will be overwritten!)</source>
         <translation>Ορισμός θεμάτων GTK (τα αρχεία διαμόρφωσης του GTK θα αντικατασταθούν!)</translation>
     </message>
     <message>
-        <location filename="../styleconfig.ui" line="62"/>
+        <location filename="../styleconfig.ui" line="274"/>
         <source>GTK 3 Theme</source>
         <translation>Θέμα GTK 3</translation>
     </message>
     <message>
-        <location filename="../styleconfig.ui" line="72"/>
+        <location filename="../styleconfig.ui" line="284"/>
         <source>GTK 2 Theme</source>
         <translation>Θέμα GTK 2</translation>
     </message>
     <message>
-        <location filename="../styleconfig.ui" line="82"/>
+        <location filename="../styleconfig.ui" line="294"/>
         <source>To attempt uniform theming, either select similar style/theme (if available) across all lists, or select &apos;gtk2&apos; Qt style (if available) to mimic GTK themes.
 
 Make sure &apos;xsettingsd&apos; is installed to help GTK applications apply themes on the fly.</source>
-        <translation>Για να καταφέρετε μια ομοιόμορφη θεματοποίηση, μπορείτε είτε να επιλέξετε ένα παρεμφερές θέμα/ύφος (αν είναι διαθέσιμο) από τα κατάστιχα, είτε να επιλέξετε το ύφος Qt &apos;gtk&apos; (αν είναι διαθέσιμο) για την μίμηση των θεμάτων GTK.
+        <translation>Για να καταφέρετε μια ομοιόμορφη θεματοποίηση, μπορείτε είτε να επιλέξετε ένα παρεμφερές θέμα/τεχνοτροπία (αν είναι διαθέσιμο) από τα κατάστιχα, είτε να επιλέξετε την τεχνοτροπία Qt &apos;gtk&apos; (αν είναι διαθέσιμη) για την μίμηση των θεμάτων GTK.
 
 Σιγουρευτείτε ότι το &apos;xsettingsd&apos; είναι εγκατεστημένο ούτως ώστε να βοηθήσετε τις εφαρμογές GTK να εφαρμόζουν τα θέματα σε πραγματικό χρόνο.</translation>
     </message>
     <message>
-        <location filename="../styleconfig.ui" line="99"/>
+        <location filename="../styleconfig.ui" line="311"/>
         <source>Toolbar button style:</source>
-        <translation>Ύφος των κουμπιών της γραμμής εργαλείων:</translation>
+        <translation>Τεχνοτροπία των κουμπιών της γραμμής εργαλείων:</translation>
     </message>
     <message>
-        <location filename="../styleconfig.ui" line="107"/>
+        <location filename="../styleconfig.ui" line="319"/>
         <source>Only display the icon</source>
         <translation>Εμφάνιση μόνον του εικονιδίου</translation>
     </message>
     <message>
-        <location filename="../styleconfig.ui" line="112"/>
+        <location filename="../styleconfig.ui" line="324"/>
         <source>Only display the text</source>
         <translation>Εμφάνιση μόνον του κειμένου</translation>
     </message>
     <message>
-        <location filename="../styleconfig.ui" line="117"/>
+        <location filename="../styleconfig.ui" line="329"/>
         <source>The text appears beside the icon</source>
         <translation>Το κείμενο εμφανίζεται δίπλα από το εικονίδιο</translation>
     </message>
     <message>
-        <location filename="../styleconfig.ui" line="122"/>
+        <location filename="../styleconfig.ui" line="334"/>
         <source>The text appears under the icon</source>
         <translation>Το κείμενο εμφανίζεται κάτω από το εικονίδιο</translation>
     </message>
     <message>
-        <location filename="../styleconfig.ui" line="127"/>
+        <location filename="../styleconfig.ui" line="339"/>
         <source>Default</source>
         <translation>Εξ ορισμού</translation>
     </message>
     <message>
-        <location filename="../styleconfig.ui" line="135"/>
+        <location filename="../styleconfig.ui" line="347"/>
         <source>Activate item on single click</source>
         <translation>Ενεργοποίηση των αντικειμένων με μονό κλικ</translation>
     </message>
     <message>
-        <location filename="../styleconfig.ui" line="145"/>
+        <location filename="../styleconfig.ui" line="51"/>
         <source>Qt Style</source>
-        <translation>Ύφος Qt</translation>
+        <translation>Τεχνοτροπία Qt</translation>
     </message>
 </context>
 </TS>
