@@ -1,21 +1,21 @@
 /*  This file is part of the KDE project
  *    Copyright (C) 2010 Lukas Tinkl <ltinkl@redhat.com>
  *    Copyright (C) 2015 Kai Uwe Broulik <kde@privat.broulik.de>
- * 
+ *
  *    This library is free software; you can redistribute it and/or
  *    modify it under the terms of the GNU Library General Public
  *    License version 2 as published by the Free Software Foundation.
- * 
+ *
  *    This library is distributed in the hope that it will be useful,
  *    but WITHOUT ANY WARRANTY; without even the implied warranty of
  *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  *    Library General Public License for more details.
- * 
+ *
  *    You should have received a copy of the GNU Library General Public License
  *    along with this library; see the file COPYING.LIB.  If not, write to
  *    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
  *    Boston, MA 02110-1301, USA.
- * 
+ *
  */
 
 
@@ -139,38 +139,38 @@ float XRandrBrightness::gamma_brightness_get(xcb_randr_output_t output)
     xcb_generic_error_t  *error;
 
     xcb_randr_get_output_info_cookie_t output_info_cookie = xcb_randr_get_output_info (QX11Info::connection(), output, 0);
-    xcb_randr_get_output_info_reply_t * output_info = xcb_randr_get_output_info_reply (QX11Info::connection(), output_info_cookie, &error);
-    if(error != NULL)
+    ScopedCPointer<xcb_randr_get_output_info_reply_t> output_info(xcb_randr_get_output_info_reply (QX11Info::connection(), output_info_cookie, &error));
+    if(error != nullptr)
     {
         qDebug() << "Error getting output_info";
         return -1;
     }
-    if(output_info == NULL)
+    if(output_info == nullptr)
     {
         qDebug() << "Error: output_info is null";
         return -1;
     }
     // xcb_randr_get_output_info_reply_t tiene como elemento crtc
     xcb_randr_get_crtc_gamma_cookie_t gamma_cookie = xcb_randr_get_crtc_gamma_unchecked (QX11Info::connection(), output_info->crtc);
-    xcb_randr_get_crtc_gamma_reply_t *gamma_reply =  xcb_randr_get_crtc_gamma_reply (QX11Info::connection(), gamma_cookie, &error);
-    if(error != NULL)
+    ScopedCPointer<xcb_randr_get_crtc_gamma_reply_t> gamma_reply(xcb_randr_get_crtc_gamma_reply (QX11Info::connection(), gamma_cookie, &error));
+    if(error != nullptr)
     {
         qDebug() << "Error getting gamma_reply";
         return -1;
     }
-    if(gamma_reply == NULL)
+    if(gamma_reply == nullptr)
     {
         qDebug() << "Error: gamma_reply is null";
         return -1;
     }
-    uint16_t *red = xcb_randr_get_crtc_gamma_red (gamma_reply);
-    if(red == NULL)
+    uint16_t * red = xcb_randr_get_crtc_gamma_red (gamma_reply.data());
+    if(red == nullptr)
     {
         qDebug() << "Error: red is null";
         return -1;
     }
-    int red_length = xcb_randr_get_crtc_gamma_red_length(gamma_reply);
-    
+    int red_length = xcb_randr_get_crtc_gamma_red_length(gamma_reply.data());
+
     // uint16_t *green = xcb_randr_get_crtc_gamma_green (gamma_reply);
     // if(green == NULL)
     // {
@@ -193,45 +193,45 @@ void XRandrBrightness::gamma_brightness_set(xcb_randr_output_t output, float per
     xcb_generic_error_t  *error;
 
     xcb_randr_get_output_info_cookie_t output_info_cookie = xcb_randr_get_output_info (QX11Info::connection(), output, 0);
-    xcb_randr_get_output_info_reply_t * output_info = xcb_randr_get_output_info_reply (QX11Info::connection(), output_info_cookie, &error);
-    if(error != NULL)
+    ScopedCPointer<xcb_randr_get_output_info_reply_t> output_info(xcb_randr_get_output_info_reply (QX11Info::connection(), output_info_cookie, &error));
+    if(error != nullptr)
     {
         qDebug() << "Error getting output_info";
         return;
     }
-    if(output_info == NULL)
+    if(output_info == nullptr)
     {
         qDebug() << "Error: output_info is null";
         return;
     }
     // xcb_randr_get_output_info_reply_t tiene como elemento crtc
     xcb_randr_get_crtc_gamma_cookie_t gamma_cookie = xcb_randr_get_crtc_gamma_unchecked (QX11Info::connection(), output_info->crtc);
-    xcb_randr_get_crtc_gamma_reply_t *gamma_reply =  xcb_randr_get_crtc_gamma_reply (QX11Info::connection(), gamma_cookie, &error);
-    if(error != NULL)
+    ScopedCPointer<xcb_randr_get_crtc_gamma_reply_t> gamma_reply(xcb_randr_get_crtc_gamma_reply (QX11Info::connection(), gamma_cookie, &error));
+    if(error != nullptr)
     {
         qDebug() << "Error getting gamma_reply";
         return;
     }
-    if(gamma_reply == NULL)
+    if(gamma_reply == nullptr)
     {
         qDebug() << "Error: gamma_reply is null";
         return;
     }
-    uint16_t *red = xcb_randr_get_crtc_gamma_red (gamma_reply);
-    if(red == NULL)
+    uint16_t *red = xcb_randr_get_crtc_gamma_red (gamma_reply.data());
+    if(red == nullptr)
     {
         qDebug() << "Error: red is null";
         return;
     }
-    int red_length = xcb_randr_get_crtc_gamma_red_length(gamma_reply);
-    uint16_t *green = xcb_randr_get_crtc_gamma_green (gamma_reply);
-    if(green == NULL)
+    int red_length = xcb_randr_get_crtc_gamma_red_length(gamma_reply.data());
+    uint16_t *green = xcb_randr_get_crtc_gamma_green (gamma_reply.data());
+    if(green == nullptr)
     {
         qDebug() << "Error: green is null";
         return;
     }
-    uint16_t *blue = xcb_randr_get_crtc_gamma_blue (gamma_reply);
-    if(blue == NULL)
+    uint16_t *blue = xcb_randr_get_crtc_gamma_blue (gamma_reply.data());
+    if(blue == nullptr)
     {
         qDebug() << "Error: blue is null";
         return;
@@ -262,21 +262,21 @@ QList<MonitorInfo> XRandrBrightness::getMonitorsInfo()
         xcb_generic_error_t  *error;
 
         xcb_randr_get_output_info_cookie_t output_info_cookie = xcb_randr_get_output_info (QX11Info::connection(), output, 0);
-        xcb_randr_get_output_info_reply_t * output_info = xcb_randr_get_output_info_reply (QX11Info::connection(), output_info_cookie, &error);
-        if(error != NULL)
+        ScopedCPointer <xcb_randr_get_output_info_reply_t> output_info(xcb_randr_get_output_info_reply (QX11Info::connection(), output_info_cookie, &error));
+        if(error != nullptr)
         {
             qDebug() << "Error getting output_info";
             continue;
         }
-        if(output_info == NULL)
+        if(output_info == nullptr)
         {
             qDebug() << "Error: output_info is null";
             continue;
         }
 
-        QString name = QString::fromUtf8((const char *) xcb_randr_get_output_info_name(output_info), output_info->name_len);
+        QString name = QString::fromUtf8((const char *) xcb_randr_get_output_info_name(output_info.data()), output_info->name_len);
+
 
-    
         qDebug() << "Found output:" << name;
 
 
@@ -294,13 +294,13 @@ QList<MonitorInfo> XRandrBrightness::getMonitorsInfo()
             continue;
         }
         xcb_randr_get_crtc_info_cookie_t crtc_info_cookie = xcb_randr_get_crtc_info_unchecked (QX11Info::connection(), output_info->crtc, 0);
-        xcb_randr_get_crtc_info_reply_t *crtc_info =xcb_randr_get_crtc_info_reply (QX11Info::connection(), crtc_info_cookie, &error);
-        if(error != NULL)
+        ScopedCPointer<xcb_randr_get_crtc_info_reply_t> crtc_info(xcb_randr_get_crtc_info_reply (QX11Info::connection(), crtc_info_cookie, &error));
+        if(error != nullptr)
         {
             qDebug() << "Error getting output_info";
             continue;
         }
-        if(crtc_info == NULL)
+        if(crtc_info == nullptr)
         {
             qDebug() << "Error: output_info is null";
             continue;
@@ -311,7 +311,7 @@ QList<MonitorInfo> XRandrBrightness::getMonitorsInfo()
             continue;
         }
 
-        // Output is connected and enabled. Get data: 
+        // Output is connected and enabled. Get data:
         bool backlightIsSuported = false;
         long cur, min, max, backlight_max = -1;
         if (backlight_get(output) != -1)
@@ -319,20 +319,20 @@ QList<MonitorInfo> XRandrBrightness::getMonitorsInfo()
             if (backlight_get_with_range(output, cur, min, max))
             {
                 backlightIsSuported = true;
-                backlight_max = max - min; 
+                backlight_max = max - min;
             }
         }
-        
+
         MonitorInfo monitor((int)output, name, backlight_max);
 
         if(backlightIsSuported)
             monitor.setBacklight(cur-min);
-        
+
         monitor.setBrightness(gamma_brightness_get(output));
-       
+
         qDebug() << "Output:" << name << "added";
-        monitors.append(monitor); 
-        
+        monitors.append(monitor);
+
     }
 
     return monitors;
@@ -351,13 +351,13 @@ void XRandrBrightness::setMonitorsSettings(QList<MonitorInfo> monitors)
         xcb_generic_error_t  *error;
 
         xcb_randr_get_output_info_cookie_t output_info_cookie = xcb_randr_get_output_info (QX11Info::connection(), output, 0);
-        xcb_randr_get_output_info_reply_t * output_info = xcb_randr_get_output_info_reply (QX11Info::connection(), output_info_cookie, &error);
-        if(error != NULL)
+        ScopedCPointer<xcb_randr_get_output_info_reply_t> output_info(xcb_randr_get_output_info_reply (QX11Info::connection(), output_info_cookie, &error));
+        if(error != nullptr)
         {
             qDebug() << "Error getting output_info";
             continue;
         }
-        if(output_info == NULL)
+        if(output_info == nullptr)
         {
             qDebug() << "Error: output_info is null";
             continue;
@@ -371,15 +371,15 @@ void XRandrBrightness::setMonitorsSettings(QList<MonitorInfo> monitors)
         if( output_info->crtc == 0)
             continue;
         xcb_randr_get_crtc_info_cookie_t crtc_info_cookie = xcb_randr_get_crtc_info_unchecked (QX11Info::connection(), output_info->crtc, 0);
-        xcb_randr_get_crtc_info_reply_t *crtc_info =xcb_randr_get_crtc_info_reply (QX11Info::connection(), crtc_info_cookie, &error);
-        if(error != NULL)
+        ScopedCPointer<xcb_randr_get_crtc_info_reply_t> crtc_info(xcb_randr_get_crtc_info_reply (QX11Info::connection(), crtc_info_cookie, &error));
+        if(error != nullptr)
             continue;
-        if(crtc_info == NULL && crtc_info->mode == XCB_NONE )
+        if(crtc_info == nullptr || crtc_info->mode == XCB_NONE )
             continue;
 
-        QString name = QString::fromUtf8((const char *) xcb_randr_get_output_info_name(output_info), output_info->name_len);
+        QString name = QString::fromUtf8((const char *) xcb_randr_get_output_info_name(output_info.data()), output_info->name_len);
 
-        // Output is connected and enabled. Get data: 
+        // Output is connected and enabled. Get data:
         bool backlightIsSuported = false;
         long cur, min, max, backlight_value = 0;
         if (backlight_get(output) != -1)
@@ -395,6 +395,7 @@ void XRandrBrightness::setMonitorsSettings(QList<MonitorInfo> monitors)
         // Compare output info with settings and set it.
         for(const MonitorInfo &monitor: monitors)
         {
+            //qDebug() << "[XRandrBrightness::setMonitorsSettings]" << monitor.id() << (int)output << monitor.name() << name ;
             if(monitor.id() == (int)output && monitor.name() == name)
             {
                 // Set settings
