@@ -36,10 +36,20 @@ class ApplicationChooser : public QDialog
 {
     Q_OBJECT
 public:
-    ApplicationChooser(const XdgMimeType& mimeInfo, bool showUseAlwaysCheckBox = false);
+    enum category {
+        none,
+        webBrowser,
+        emailClient,
+        fileManager
+    };
+
+    ApplicationChooser(const QString& type, int cat = category::none);
 
     virtual ~ApplicationChooser();
-    XdgDesktopFile* DefaultApplication() const { return m_CurrentDefaultApplication; }
+
+    XdgDesktopFile* DefaultApplication() const {
+        return m_CurrentDefaultApplication; // should be deleted by the caller
+    }
 
     virtual int exec();
 
@@ -53,9 +63,11 @@ private:
     void addApplicationsToApplicationListWidget(QTreeWidgetItem* parent,
                                                 QList<XdgDesktopFile*> applications,
                                                 QSet<XdgDesktopFile*> & alreadyAdded);
-    XdgMimeType m_MimeInfo;
+    QString m_Type;
+    int m_Cat;
     Ui::ApplicationChooser widget;
     XdgDesktopFile* m_CurrentDefaultApplication;
+    QSet<XdgDesktopFile*> allApps; // all app pointers that should be deleted in d-tor
 };
 
 #endif	/* _APPLICATIONCHOOSER_H */
