@@ -64,7 +64,7 @@
         <location filename="../keyboardconfig.ui" line="150"/>
         <location filename="../keyboardconfig.ui" line="157"/>
         <source>0</source>
-        <translation></translation>
+        <translation>0</translation>
     </message>
     <message>
         <location filename="../keyboardconfig.ui" line="167"/>
@@ -77,7 +77,7 @@
     <message>
         <location filename="../keyboardlayoutconfig.ui" line="20"/>
         <source>&lt;b&gt;Keyboard Layout&lt;/b&gt;</source>
-        <translation>&lt;b&gt;Billentyűkiosztás&lt;/b&gt;</translation>
+        <translation>&lt;b&gt;Billentyűzetkiosztás&lt;/b&gt;</translation>
     </message>
     <message>
         <location filename="../keyboardlayoutconfig.ui" line="48"/>
@@ -144,67 +144,26 @@
     </message>
     <message>
         <location filename="../mouseconfig.ui" line="30"/>
-        <source>Motion</source>
-        <translation>Mozgás</translation>
-    </message>
-    <message>
-        <location filename="../mouseconfig.ui" line="36"/>
-        <source>High</source>
-        <translation>Magas</translation>
-    </message>
-    <message>
-        <location filename="../mouseconfig.ui" line="43"/>
-        <source>Fast</source>
-        <translation>Gyors</translation>
-    </message>
-    <message>
-        <location filename="../mouseconfig.ui" line="50"/>
-        <source>Sensitivity:</source>
-        <translation>Érzékenység:</translation>
-    </message>
-    <message>
-        <location filename="../mouseconfig.ui" line="57"/>
-        <source>Low</source>
-        <translation>Alacsony</translation>
-    </message>
-    <message>
-        <location filename="../mouseconfig.ui" line="83"/>
-        <source>Acceleration:</source>
-        <translation>Gyorsulás:</translation>
-    </message>
-    <message>
-        <location filename="../mouseconfig.ui" line="109"/>
-        <source>Slow</source>
-        <translation>Lassú</translation>
-    </message>
-    <message>
-        <location filename="../mouseconfig.ui" line="116"/>
-        <location filename="../mouseconfig.ui" line="123"/>
-        <source>0</source>
-        <translation></translation>
-    </message>
-    <message>
-        <location filename="../mouseconfig.ui" line="133"/>
         <source>Double click interval:</source>
-        <translation>Duplakattintás időköze:</translation>
+        <translation>Dupla kattintás időköze:</translation>
     </message>
     <message>
-        <location filename="../mouseconfig.ui" line="140"/>
+        <location filename="../mouseconfig.ui" line="37"/>
         <source> ms</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../mouseconfig.ui" line="150"/>
+        <location filename="../mouseconfig.ui" line="47"/>
         <source>Wheel scroll lines:</source>
         <translation>Sorok egy görgetésnél:</translation>
     </message>
     <message>
-        <location filename="../mouseconfig.ui" line="160"/>
+        <location filename="../mouseconfig.ui" line="64"/>
         <source>Left handed (Swap left and right mouse buttons)</source>
         <translation>Balkezes (Bal és jobb gombok cseréje)</translation>
     </message>
     <message>
-        <location filename="../mouseconfig.ui" line="167"/>
+        <location filename="../mouseconfig.ui" line="57"/>
         <source>Single click to activate items</source>
         <translation>Egykattintásos mód</translation>
     </message>
@@ -214,7 +173,7 @@
     <message>
         <location filename="../lxqt-config-input.cpp" line="70"/>
         <source>Keyboard and Mouse Settings</source>
-        <translation>Billentyű és egérbeállítás</translation>
+        <translation>Billentyűzet és egér beállítása</translation>
     </message>
     <message>
         <location filename="../lxqt-config-input.cpp" line="79"/>
@@ -239,7 +198,7 @@
     <message>
         <location filename="../lxqt-config-input.cpp" line="112"/>
         <source>Mouse and Touchpad</source>
-        <translation>Egér és érintőtábla</translation>
+        <translation>Egér és érintőpad</translation>
     </message>
 </context>
 <context>
@@ -265,7 +224,7 @@
     <message>
         <location filename="../touchpadconfig.ui" line="14"/>
         <source>TouchpadConfig </source>
-        <translation>Érintőtábla konfiguráció </translation>
+        <translation>Érintőpad beállítása </translation>
     </message>
     <message>
         <location filename="../touchpadconfig.ui" line="20"/>
@@ -280,7 +239,7 @@
     <message>
         <location filename="../touchpadconfig.ui" line="37"/>
         <source>Tap to click</source>
-        <translation>Koppintson a kattintáshoz</translation>
+        <translation>Koppintás a kattintáshoz</translation>
     </message>
     <message>
         <location filename="../touchpadconfig.ui" line="44"/>
@@ -290,7 +249,7 @@
     <message>
         <location filename="../touchpadconfig.ui" line="51"/>
         <source>Tap and drag</source>
-        <translation>Érintse meg és húzza</translation>
+        <translation>Érintés és húzás</translation>
     </message>
     <message>
         <location filename="../touchpadconfig.ui" line="79"/>
@@ -300,22 +259,42 @@
     <message>
         <location filename="../touchpadconfig.ui" line="102"/>
         <source>&amp;Disabled</source>
-        <translation>&amp;Kikapcsolva</translation>
+        <translation>K&amp;ikapcsolva</translation>
     </message>
     <message>
         <location filename="../touchpadconfig.ui" line="109"/>
         <source>&amp;Two-Finger</source>
-        <translation type="unfinished">&amp;Kétujjas</translation>
+        <translation>&amp;Kétujjas</translation>
     </message>
     <message>
         <location filename="../touchpadconfig.ui" line="116"/>
         <source>Ed&amp;ge</source>
-        <translation type="unfinished">&amp;Széle</translation>
+        <translation>&amp;Széle</translation>
     </message>
     <message>
         <location filename="../touchpadconfig.ui" line="123"/>
         <source>B&amp;utton</source>
-        <translation type="unfinished">Go&amp;mb</translation>
+        <translation>&amp;Gomb</translation>
+    </message>
+    <message>
+        <location filename="../touchpadconfig.ui" line="145"/>
+        <source>DeviceInfoLabel</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../touchpadconfig.cpp" line="85"/>
+        <source>LXQt only supports &quot;libinput&quot; as xinput driver.
+(current value: %1)
+
+If this is intended, please configure xinput manually.
+Otherwise you can get rid of this message by changing xinput driver to &quot;libinput&quot;.
+</source>
+        <translation type="unfinished">Az LXQt csak a &quot;libinput&quot;-ot támogatja xinput driverként.
+(jelenlegi érték: %1)
+
+Ha ez szándékos, állítsa be manuálisan az xinput-ot.
+Ellenkező esetben megszabadulhat ettől az üzenettől, ha az xinput drivert &quot;libinput&quot;-ra változtatja.
+</translation>
     </message>
 </context>
 </TS>
