@@ -41,7 +41,7 @@
 #include <lxqtautostartentry.h>
 
 MonitorSettingsDialog::MonitorSettingsDialog() :
-    QDialog(nullptr, nullptr)
+    QDialog(nullptr, Qt::WindowFlags())
 {
     ui.setupUi(this);
 
@@ -93,7 +93,7 @@ void MonitorSettingsDialog::loadConfiguration(KScreen::ConfigPtr config)
 
     MonitorPictureDialog *monitorPicture = nullptr;
     FastMenu *fastMenu = nullptr;
-    KScreen::OutputList outputs = mConfig->outputs();
+    const KScreen::OutputList outputs = mConfig->outputs();
 
     int nMonitors = 0;
     for (const KScreen::OutputPtr &output : outputs) {
@@ -164,7 +164,7 @@ void MonitorSettingsDialog::saveConfiguration(KScreen::ConfigPtr config)
 {
 
     QList<MonitorSettings> currentSettings;
-    KScreen::OutputList outputs = config->outputs();
+    const KScreen::OutputList outputs = config->outputs();
     for (const KScreen::OutputPtr &output : outputs) {
         MonitorSettings monitor;
         monitor.name = output->name();
@@ -178,9 +178,11 @@ void MonitorSettingsDialog::saveConfiguration(KScreen::ConfigPtr config)
             monitor.xPos = output->pos().x();
             monitor.yPos = output->pos().y();
             monitor.currentMode = output->currentModeId();
-            monitor.currentModeWidth = output->currentMode()->size().width();
-            monitor.currentModeHeight = output->currentMode()->size().height();
-            monitor.currentModeRate = output->currentMode()->refreshRate();
+            if (output->currentMode()) {
+                monitor.currentModeWidth = output->currentMode()->size().width();
+                monitor.currentModeHeight = output->currentMode()->size().height();
+                monitor.currentModeRate = output->currentMode()->refreshRate();
+            }
             monitor.rotation = output->rotation();
         }
         currentSettings.append(monitor);
