@@ -46,8 +46,8 @@ class MonitorWidget : public QGroupBox
   friend class MonitorPictureDialog;
 
 public:
-    MonitorWidget(KScreen::OutputPtr output, KScreen::ConfigPtr config, QWidget* parent = 0);
-    ~MonitorWidget();
+    MonitorWidget(KScreen::OutputPtr output, KScreen::ConfigPtr config, QWidget* parent = nullptr);
+    ~MonitorWidget() override;
 
     void updateRefreshRates();
 
