@@ -33,13 +33,15 @@
 #include "qcategorizedview.h"
 #include "qcategorizedview_p.h"
 
-#include <math.h> // trunc on C99 compliant systems
+#include <cmath> // trunc on C99 compliant systems
 //#include <kdefakes.h> // trunc for not C99 compliant systems
 
 #include <QPainter>
 #include <QScrollBar>
 #include <QPaintEvent>
 
+#include <algorithm>
+
 #include "qcategorydrawer.h"
 #include "qcategorizedsortfilterproxymodel.h"
 
@@ -107,10 +109,10 @@ struct QCategorizedView::Private::Block
 
 QCategorizedView::Private::Private(QCategorizedView *q)
     : q(q)
-    , proxyModel(0)
-    , categoryDrawer(0)
-    , categoryDrawerV2(0)
-    , categoryDrawerV3(0)
+    , proxyModel(nullptr)
+    , categoryDrawer(nullptr)
+    , categoryDrawerV2(nullptr)
+    , categoryDrawerV3(nullptr)
     , categorySpacing(5)
     , alternatingBlockColors(false)
     , collapsibleBlocks(false)
@@ -328,7 +330,7 @@ void QCategorizedView::Private::rowsInserted(const QModelIndex &parent, int star
         const QModelIndex firstAffectedCategory = blocks[category].firstIndex;
         //BEGIN: order for marking as alternate those blocks that are alternate
         QList<Block> blockList = blocks.values();
-        qSort(blockList.begin(), blockList.end(), Block::lessThan);
+        std::sort(blockList.begin(), blockList.end(), Block::lessThan);
         QList<int> firstIndexesRows;
         for (const Block &block : qAsConst(blockList)) {
             firstIndexesRows << block.firstIndex.row();
@@ -833,7 +835,7 @@ void QCategorizedView::paintEvent(QPaintEvent *event)
         int indexToCheckIfBlockCollapsed = i;
         QModelIndex categoryIndex;
         QString category;
-        Private::Block *block = 0;
+        Private::Block *block = nullptr;
         while (i <= intersecting.second.row()) {
             //BEGIN: first check if the block is collapsed. if so, we have to skip the item painting
             if (i == indexToCheckIfBlockCollapsed) {
@@ -1335,7 +1337,7 @@ void QCategorizedView::rowsAboutToBeRemoved(const QModelIndex &parent,
     {
         //BEGIN: order for marking as alternate those blocks that are alternate
         QList<Private::Block> blockList = d->blocks.values();
-        qSort(blockList.begin(), blockList.end(), Private::Block::lessThan);
+        std::sort(blockList.begin(), blockList.end(), Private::Block::lessThan);
         QList<int> firstIndexesRows;
         for (const Private::Block &block : qAsConst(blockList)) {
             firstIndexesRows << block.firstIndex.row();
